#
# spec file for package osmo-ggsn
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           osmo-ggsn
%define lname	libgtp3
Version:        1.2.2
Release:        0
Summary:        GPRS Support Node
License:        GPL-2.0-only AND LGPL-2.1-or-later
Group:          Productivity/Telephony/Servers
URL:            https://osmocom.org/projects/openggsn/wiki/OsmoGGSN
Source:         %name-%version.tar.xz
Patch1:         build-fixes.diff
BuildRequires:  libtool >= 2
BuildRequires:  pkgconfig >= 0.20
BuildRequires:  systemd-rpm-macros
BuildRequires:  xz
BuildRequires:  pkgconfig(libgtpnl) >= 1.2.0
BuildRequires:  pkgconfig(libmnl) >= 1.0.3
BuildRequires:  pkgconfig(libosmocore) >= 0.11.0
BuildRequires:  pkgconfig(libosmoctrl) >= 0.11.0
BuildRequires:  pkgconfig(libosmogsm)
BuildRequires:  pkgconfig(libosmovty) >= 0.11.0
Obsoletes:      openggsn
%{?systemd_requires}

%description
Osmo-GGSN is a C-language implementation of a GGSN (Gateway GPRS
Support Node), a core network element of ETSI/3GPP cellular networks
such as GPRS, EDGE, UMTS or HSPA.

%package -n %lname
Summary:        Library implementing GTP between SGSN and GGSN
License:        GPL-2.0-only
Group:          System/Libraries

%description -n %lname
libgtp implements the GPRS Tunneling Protocol between SGSN and GGSN.

%package -n libgtp-devel
Summary:        Development files for the GTP library
License:        GPL-2.0-only
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description -n libgtp-devel
libgtp implements the GPRS Tunneling Protocol between SGSN and GGSN.

This subpackage contains libraries and header files for developing
applications that want to make use of libgtp.

%prep
%autosetup -p1

%build
echo "%version" >.tarball-version
autoreconf -fi
%configure --disable-static --docdir="%_docdir/%name" \
	--includedir="%_includedir/%name"
make %{?_smp_mflags} V=1

%install
b="%buildroot"
%make_install
find $b -type f -name "*.la" -delete -print
install -D -m 0644 contrib/osmo-ggsn.service "$b/%_unitdir/%name.service"
install -d "$b/%_sbindir"
ln -s "%_sbindir/service" "$b/%_sbindir/rc%name"
install -d "$b/%_sysconfdir/osmocom"
install -m 0644 doc/examples/osmo-ggsn.cfg "$b/%_sysconfdir/osmocom/osmo-ggsn.cfg"
install -m 0644 doc/examples/sgsnemu.conf "$b/%_sysconfdir/osmocom/sgsnemu.conf"

%pre
%service_add_pre %name.service

%post
%service_add_post %name.service

%preun
%service_del_preun %name.service

%postun
%service_del_postun %name.service

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%doc AUTHORS COPYING README.md
%_sbindir/osmo-ggsn
%_sbindir/sgsnemu
%_mandir/man8/osmo-ggsn.8%ext_man
%_mandir/man8/sgsnemu.8%ext_man
%_unitdir/%name.service
%_sbindir/rc%name
%dir %_docdir/%name/examples
%_docdir/%name/examples/osmo-ggsn.cfg
%dir %_sysconfdir/osmocom
%config(noreplace) %_sysconfdir/osmocom/osmo-ggsn.cfg
%config(noreplace) %_sysconfdir/osmocom/sgsnemu.conf

%files -n %lname
%_libdir/libgtp.so.3*

%files -n libgtp-devel
%_includedir/%name/
%_libdir/libgtp.so
%_libdir/pkgconfig/libgtp.pc

%changelog
